"use strict";

exports.__esModule = true;
exports.default = void 0;

var _path = require("path");

var _utils = require("./utils");

// require('debug-utils').install();
const resolveDirname = (path, opts, fileOpts) => {
  const _opts$ignoreDirWithDo = opts.ignoreDirWithDots,
        ignoreDirWithDots = _opts$ignoreDirWithDo === void 0 ? true : _opts$ignoreDirWithDo;
  const filename = fileOpts.filename; // Only process absolute or relative paths without extensions (eg. exclude regular modules)

  const hasExtension = !!(0, _path.extname)(path);
  const isAbsolutePath = (0, _path.isAbsolute)(path);
  const isRelativePath = (0, _utils.isRelative)(path); // d({hasExtension, isAbsolutePath, isRelativePath});

  if (ignoreDirWithDots && hasExtension || !(isAbsolutePath || isRelativePath)) {
    return path;
  }

  let nextPath = path;
  const pathBasename = (0, _path.basename)(path);
  const fileDirname = (0, _path.dirname)(filename);
  const fileExtname = (0, _path.extname)(filename);
  const targetPath = isRelativePath ? (0, _path.resolve)(fileDirname, path) : path;

  if ((0, _utils.isDirectory)(targetPath) && !(0, _utils.isFile)((0, _path.join)(targetPath, `index${fileExtname}`))) {
    nextPath = `${path}/${pathBasename}`;
  }

  return nextPath;
};

var _default = ({
  types: t
}) => {
  const visitor = {
    CallExpression(path, state) {
      if (!(path.node.callee.name === 'require' || t.isImport(path.node.callee))) {
        return;
      }

      const args = path.node.arguments;

      if (!args.length) {
        return;
      }

      const firstArg = (0, _utils.traverseExpression)(t, args[0]);

      if (firstArg) {
        firstArg.value = resolveDirname(firstArg.value, state.opts, state.file.opts);
      }
    },

    ImportDeclaration(path, state) {
      path.node.source.value = resolveDirname(path.node.source.value, state.opts, state.file.opts); // eslint-disable-line no-param-reassign
    },

    ExportNamedDeclaration(path, state) {
      if (path.node.source) {
        path.node.source.value = resolveDirname(path.node.source.value, state.opts, state.file.opts); // eslint-disable-line no-param-reassign
      }
    },

    ExportAllDeclaration(path, state) {
      if (path.node.source) {
        path.node.source.value = resolveDirname(path.node.source.value, state.opts, state.file.opts); // eslint-disable-line no-param-reassign
      }
    }

  };
  return {
    visitor: {
      Program(path, state) {
        path.traverse(visitor, state);
      }

    }
  };
};

exports.default = _default;
//# sourceMappingURL=index.js.map