"use strict";

exports.__esModule = true;
exports.traverseExpression = exports.isFile = exports.isDirectory = exports.isRelative = void 0;

var _fs = require("fs");

const isRelative = path => /^\.{1,2}\/.+/.test(path);

exports.isRelative = isRelative;

const isDirectory = filepath => {
  try {
    return (0, _fs.lstatSync)(filepath).isDirectory();
  } catch (err) {
    return false;
  }
};

exports.isDirectory = isDirectory;

const isFile = filepath => {
  try {
    return (0, _fs.lstatSync)(filepath).isFile();
  } catch (err) {
    return false;
  }
};
/**
 * Recursively traverses binary  expressions to find the first `StringLiteral` if any.
 * @param  {Object} t           Babel types
 * @param  {Node} arg           a Babel node
 * @return {StringLiteral?}
 */


exports.isFile = isFile;

const traverseExpression = (t, arg) => {
  if (t.isStringLiteral(arg)) {
    return arg;
  }

  if (t.isBinaryExpression(arg)) {
    return traverseExpression(t, arg.left);
  }

  return null;
};

exports.traverseExpression = traverseExpression;
//# sourceMappingURL=utils.js.map